@@ -10,15 +10,15 @@ module Config
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["PATCHLEVEL"] = "352"
+  CONFIG["PATCHLEVEL"] = "357"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby18"
   CONFIG["RUBY_INSTALL_NAME"] = "ruby18"
   CONFIG["RUBY_SO_NAME"] = "ruby18"
-  CONFIG["MANTYPE"] = "man"
-  CONFIG["NROFF"] = "/bin/false"
+  CONFIG["MANTYPE"] = "doc"
+  CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["configure_args"] = " '--program-suffix=18' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'YACC=yacc'"
   CONFIG["vendordir"] = "$(libdir)/ruby/vendor_ruby"
   CONFIG["sitedir"] = "$(libdir)/ruby/site_ruby"
@@ -90,7 +90,7 @@ module Config
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "yes"
-  CONFIG["EGREP"] = "/usr/bin/grep -E"
+  CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "cc -E"
   CONFIG["OBJEXT"] = "o"
@@ -98,18 +98,18 @@ module Config
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC $(cflags)"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.0"
+  CONFIG["target_os"] = "openbsd5.1"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "arm"
-  CONFIG["target"] = "arm-unknown-openbsd5.0"
-  CONFIG["host_os"] = "openbsd5.0"
+  CONFIG["target"] = "arm-unknown-openbsd5.1"
+  CONFIG["host_os"] = "openbsd5.1"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "arm"
-  CONFIG["host"] = "arm-unknown-openbsd5.0"
-  CONFIG["build_os"] = "openbsd5.0"
+  CONFIG["host"] = "arm-unknown-openbsd5.1"
+  CONFIG["build_os"] = "openbsd5.1"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "arm"
-  CONFIG["build"] = "arm-unknown-openbsd5.0"
+  CONFIG["build"] = "arm-unknown-openbsd5.1"
   CONFIG["TEENY"] = "7"
   CONFIG["MINOR"] = "8"
   CONFIG["MAJOR"] = "1"
