@@ -10,7 +10,7 @@ module Config
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["PATCHLEVEL"] = "352"
+  CONFIG["PATCHLEVEL"] = "357"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
@@ -90,7 +90,7 @@ module Config
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["GNU_LD"] = "yes"
-  CONFIG["EGREP"] = "/usr/bin/grep -E"
+  CONFIG["EGREP"] = "/usr/bin/egrep"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "cc -E"
   CONFIG["OBJEXT"] = "o"
@@ -98,18 +98,18 @@ module Config
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC $(cflags)"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.0"
+  CONFIG["target_os"] = "openbsd5.1"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64"
-  CONFIG["target"] = "mips64-unknown-openbsd5.0"
-  CONFIG["host_os"] = "openbsd5.0"
+  CONFIG["target"] = "mips64-unknown-openbsd5.1"
+  CONFIG["host_os"] = "openbsd5.1"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64"
-  CONFIG["host"] = "mips64-unknown-openbsd5.0"
-  CONFIG["build_os"] = "openbsd5.0"
+  CONFIG["host"] = "mips64-unknown-openbsd5.1"
+  CONFIG["build_os"] = "openbsd5.1"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64"
-  CONFIG["build"] = "mips64-unknown-openbsd5.0"
+  CONFIG["build"] = "mips64-unknown-openbsd5.1"
   CONFIG["TEENY"] = "7"
   CONFIG["MINOR"] = "8"
   CONFIG["MAJOR"] = "1"
